# Generated by Django 4.2.7 on 2023-11-23 15:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_time_block', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='timeblock',
            name='object_id',
            field=models.TextField(),
        ),
        migrations.AddIndex(
            model_name='timeblock',
            index=models.Index(fields=['object_id', 'start_datetime'], name='django_time_object__c52a78_idx'),
        ),
    ]
